@@ -36,6 +36,7 @@ import six
 import logging
 import numpy as np
 import matplotlib
+from metpy.units import units
 from fs import open_fs
 from fslib.fs_filepicker import getSaveFileNameAndFilter
 from matplotlib import cbook, figure
@@ -495,6 +496,8 @@ class MplSideViewCanvas(MplCanvas):
         self.settings_dict = {"vertical_extent": (1050, 180),
                               "vertical_axis": "pressure",
                               "secondary_axis": "no secondary axis",
+                              "plot_title_size": "default",
+                              "axes_label_size": "default",
                               "flightlevels": [],
                               "draw_flightlevels": True,
                               "draw_flighttrack": True,
@@ -520,6 +523,9 @@ class MplSideViewCanvas(MplCanvas):
         # Main axes instance of mplwidget has zorder 99.
         self.imgax = self.fig.add_axes(
             self.ax.get_position(), frameon=True, xticks=[], yticks=[], label="imgax", zorder=0)
+
+        # Sets the default value of sideview fontsize settings from MSSDefaultConfig.
+        self.sideview_size_settings = config_loader(dataset="sideview")
         self.setup_side_view()
         # Draw a number of flight level lines.
         self.flightlevels = []
@@ -555,8 +561,8 @@ class MplSideViewCanvas(MplCanvas):
 
     def _determine_ticks_labels(self, typ):
         if typ == "no secondary axis":
-            major_ticks = []
-            minor_ticks = []
+            major_ticks = [] * units.pascal
+            minor_ticks = [] * units.pascal
             labels = []
             ylabel = ""
         elif typ == "pressure":
@@ -571,8 +577,8 @@ class MplSideViewCanvas(MplCanvas):
                 labels = ["" if x.split(".")[-1][0] in "9" else x for x in labels]
             ylabel = "pressure (hPa)"
         elif typ == "pressure altitude":
-            bot_km = thermolib.pressure2flightlevel(self.p_bot) * 0.03048
-            top_km = thermolib.pressure2flightlevel(self.p_top) * 0.03048
+            bot_km = thermolib.pressure2flightlevel(self.p_bot * units.Pa).to(units.km).magnitude
+            top_km = thermolib.pressure2flightlevel(self.p_top * units.Pa).to(units.km).magnitude
             ma_dist, mi_dist = 4, 1.0
             if (top_km - bot_km) <= 20:
                 ma_dist, mi_dist = 1, 0.5
@@ -580,13 +586,13 @@ class MplSideViewCanvas(MplCanvas):
                 ma_dist, mi_dist = 2, 0.5
             major_heights = np.arange(0, top_km + 1, ma_dist)
             minor_heights = np.arange(0, top_km + 1, mi_dist)
-            major_ticks = thermolib.flightlevel2pressure_a(major_heights / 0.03048)
-            minor_ticks = thermolib.flightlevel2pressure_a(minor_heights / 0.03048)
+            major_ticks = thermolib.flightlevel2pressure(major_heights * units.km).magnitude
+            minor_ticks = thermolib.flightlevel2pressure(minor_heights * units.km).magnitude
             labels = major_heights
             ylabel = "pressure altitude (km)"
         elif typ == "flight level":
-            bot_km = thermolib.pressure2flightlevel(self.p_bot) * 0.03048
-            top_km = thermolib.pressure2flightlevel(self.p_top) * 0.03048
+            bot_km = thermolib.pressure2flightlevel(self.p_bot * units.Pa).to(units.km).magnitude
+            top_km = thermolib.pressure2flightlevel(self.p_top * units.Pa).to(units.km).magnitude
             ma_dist, mi_dist = 50, 10
             if (top_km - bot_km) <= 10:
                 ma_dist, mi_dist = 20, 10
@@ -594,8 +600,8 @@ class MplSideViewCanvas(MplCanvas):
                 ma_dist, mi_dist = 40, 10
             major_fl = np.arange(0, 2132, ma_dist)
             minor_fl = np.arange(0, 2132, mi_dist)
-            major_ticks = thermolib.flightlevel2pressure_a(major_fl)
-            minor_ticks = thermolib.flightlevel2pressure_a(minor_fl)
+            major_ticks = thermolib.flightlevel2pressure(major_fl * units.hft).magnitude
+            minor_ticks = thermolib.flightlevel2pressure(minor_fl * units.hft).magnitude
             labels = major_fl
             ylabel = "flight level (hft)"
         else:
@@ -603,19 +609,34 @@ class MplSideViewCanvas(MplCanvas):
         return ylabel, major_ticks, minor_ticks, labels
 
     def redraw_yaxis(self):
-        """ Redraws the y-axis on map after setting the values from sideview options dialog box"""
+        """ Redraws the y-axis on map after setting the values from sideview options dialog box
+        and also updates the sizes for map title and x and y axes labels and ticklabels"""
 
         vaxis = self.settings_dict["vertical_axis"]
         vaxis2 = self.settings_dict["secondary_axis"]
 
+        # Sets fontsize value for x axis ticklabel.
+        axes_label_size = (self.sideview_size_settings["axes_label_size"]
+                           if self.settings_dict["axes_label_size"] == "default"
+                           else int(self.settings_dict["axes_label_size"]))
+        # Sets fontsize value for plot title and axes title/label
+        plot_title_size = (self.sideview_size_settings["plot_title_size"]
+                           if self.settings_dict["plot_title_size"] == "default"
+                           else int(self.settings_dict["plot_title_size"]))
+        # Updates the fontsize of the x-axis ticklabels of sideview.
+        self.ax.tick_params(axis='x', labelsize=axes_label_size)
+        # Updates the fontsize of plot title and x-axis title of sideview.
+        self.ax.set_title("vertical flight profile", fontsize=plot_title_size, horizontalalignment="left", x=0)
+        self.ax.set_xlabel("lat/lon", fontsize=plot_title_size)
+
         for ax, typ in zip((self.ax, self.ax2), (vaxis, vaxis2)):
             ylabel, major_ticks, minor_ticks, labels = self._determine_ticks_labels(typ)
 
-            ax.set_ylabel(ylabel)
+            ax.set_ylabel(ylabel, fontsize=plot_title_size)
             ax.set_yticks(minor_ticks, minor=True)
             ax.set_yticks(major_ticks, minor=False)
-            ax.set_yticklabels([], minor=True, fontsize=10)
-            ax.set_yticklabels(labels, minor=False, fontsize=10)
+            ax.set_yticklabels([], minor=True)
+            ax.set_yticklabels(labels, minor=False, fontsize=axes_label_size)
             ax.set_ylim(self.p_bot, self.p_top)
 
         if vaxis2 == "no secondary axis":
@@ -634,6 +655,7 @@ class MplSideViewCanvas(MplCanvas):
 
         self.ax.set_title("vertical flight profile", horizontalalignment="left", x=0)
         self.ax.grid(b=True)
+
         self.ax.set_xlabel("lat/lon")
 
         for ax in (self.ax, self.ax2):
@@ -664,18 +686,19 @@ class MplSideViewCanvas(MplCanvas):
         lat_inds = np.arange(len(lats))
         tick_index_step = len(lat_inds) // self.numlabels
         self.ax.set_xticks(lat_inds[::tick_index_step])
+
         if self.waypoints_model is not None and self.waypoints_model.performance_settings["visible"]:
             self.ax.set_xticklabels([f'{d[0]:2.1f}, {d[1]:2.1f}\n{d[2].strftime("%H:%M")}Z'
                                      for d in zip(lats[::tick_index_step],
                                                   lons[::tick_index_step],
                                                   times[::tick_index_step])],
-                                    rotation=25, fontsize=10, horizontalalignment="right")
+                                    rotation=25, horizontalalignment="right")
         else:
             self.ax.set_xticklabels([f"{d[0]:2.1f}, {d[1]:2.1f}"
                                      for d in zip(lats[::tick_index_step],
                                                   lons[::tick_index_step],
                                                   times[::tick_index_step])],
-                                    rotation=25, fontsize=10, horizontalalignment="right")
+                                    rotation=25, horizontalalignment="right")
 
         for _line in self.ceiling_alt:
             _line.remove()
@@ -696,7 +719,7 @@ class MplSideViewCanvas(MplCanvas):
                 ys.append(aircraft.get_ceiling_altitude(wpd[-1].weight))
 
                 self.ceiling_alt = self.ax.plot(
-                    xs, thermolib.flightlevel2pressure_a(np.asarray(ys)),
+                    xs, thermolib.flightlevel2pressure(np.asarray(ys) * units.hft).magnitude,
                     color="k", ls="--")
                 self.update_ceiling(
                     self.settings_dict["draw_ceiling"] and self.waypoints_model.performance_settings["visible"],
@@ -736,7 +759,7 @@ class MplSideViewCanvas(MplCanvas):
         # Plot lines indicating flight level altitude.
         ax = self.ax
         for level in self.flightlevels:
-            pressure = thermolib.flightlevel2pressure(level)
+            pressure = thermolib.flightlevel2pressure(level * units.hft).magnitude
             self.fl_label_list.append(ax.axhline(pressure, color='k'))
             self.fl_label_list.append(ax.text(0.1, pressure, f"FL{level:d}"))
         self.draw()
@@ -868,11 +891,11 @@ class MplSideViewCanvas(MplCanvas):
             p_top_old = self.p_top
 
         if self.settings_dict["vertical_axis"] == "pressure altitude":
-            self.p_bot = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][0] * 32.80)
-            self.p_top = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][1] * 32.80)
+            self.p_bot = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][0] * units.km).magnitude
+            self.p_top = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][1] * units.km).magnitude
         elif self.settings_dict["vertical_axis"] == "flight level":
-            self.p_bot = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][0])
-            self.p_top = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][1])
+            self.p_bot = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][0] * units.hft).magnitude
+            self.p_top = thermolib.flightlevel2pressure(self.settings_dict["vertical_extent"][1] * units.hft).magnitude
         else:
             self.p_bot = self.settings_dict["vertical_extent"][0] * 100
             self.p_top = self.settings_dict["vertical_extent"][1] * 100
@@ -920,6 +943,9 @@ class MplLinearViewCanvas(MplCanvas):
             numlabels = config_loader(dataset='num_labels')
         super(MplLinearViewCanvas, self).__init__()
 
+        self.settings_dict = {"plot_title_size": "default",
+                              "axes_label_size": "default"}
+
         # Setup the plot.
         self.numlabels = numlabels
         self.setup_linear_view()
@@ -931,6 +957,10 @@ class MplLinearViewCanvas(MplCanvas):
         if model:
             self.set_waypoints_model(model)
 
+        # Sets the default values of plot sizes from MissionSupportDefaultConfig.
+        self.linearview_size_settings = config_loader(dataset="linearview")
+        self.set_settings(self.settings_dict)
+
     def set_waypoints_model(self, model):
         """Set the WaypointsTableModel defining the linear section.
         If no model had been set before, create a new interactor object on the model
@@ -949,11 +979,11 @@ class MplLinearViewCanvas(MplCanvas):
                 redraw_xaxis=self.redraw_xaxis
             )
         self.redraw_xaxis()
+        # self.set_settings(self.settings_dict)
 
     def setup_linear_view(self):
         """Set up a linear section view.
         """
-        self.ax.set_title("Linear flight profile", horizontalalignment="left", x=0)
         self.fig.subplots_adjust(left=0.08, right=0.96, top=0.9, bottom=0.14)
 
     def clear_figure(self):
@@ -997,7 +1027,7 @@ class MplLinearViewCanvas(MplCanvas):
             self.ax.set_xticklabels([f'{d[0]:2.1f}, {d[1]:2.1f}'
                                      for d in zip(lats[::tick_index_step],
                                                   lons[::tick_index_step])],
-                                    rotation=25, fontsize=10, horizontalalignment="right")
+                                    rotation=25, horizontalalignment="right")
 
             ipoint = 0
             highlight = [[wp.lat, wp.lon] for wp in self.waypoints_model.waypoints]
@@ -1043,6 +1073,29 @@ class MplLinearViewCanvas(MplCanvas):
         self.redraw_xaxis()
         self.fig.tight_layout()
         self.fig.subplots_adjust(top=0.85, bottom=0.20)
+        # self.set_settings(self.settings_dict)
+        self.draw()
+
+    def get_settings(self):
+        """Returns a dictionary containing settings regarding the linear view
+           appearance.
+        """
+        return self.settings_dict
+
+    def set_settings(self, settings):
+        """
+        Apply settings from options ui to the linear view
+        """
+
+        if settings is not None:
+            self.settings_dict.update(settings)
+
+        pts = (self.linearview_size_settings["plot_title_size"] if self.settings_dict["plot_title_size"] == "default"
+               else int(self.settings_dict["plot_title_size"]))
+        als = (self.linearview_size_settings["axes_label_size"] if self.settings_dict["axes_label_size"] == "default"
+               else int(self.settings_dict["axes_label_size"]))
+        self.ax.tick_params(axis='both', labelsize=als)
+        self.ax.set_title("Linear flight profile", fontsize=pts, horizontalalignment='left', x=0)
         self.draw()
 
 
@@ -1085,6 +1138,12 @@ class MplTopViewCanvas(MplCanvas):
         self.legax = None
         self.legimg = None
 
+        # stores the  topview plot title size(tov_pts) and topview axes label size(tov_als),initially as None.
+        self.tov_pts = None
+        self.tov_als = None
+        # Sets the default fontsize parameters' values for topview from MSSDefaultConfig.
+        self.topview_size_settings = config_loader(dataset="topview")
+
         # Set map appearance from parameter or, if not specified, to default
         # values.
         self.set_map_appearance(settings)
@@ -1100,8 +1159,18 @@ class MplTopViewCanvas(MplCanvas):
         self.map = mpl_map.MapCanvas(appearance=self.get_map_appearance(),
                                      resolution="l", area_thresh=1000., ax=ax,
                                      **kwargs)
+
+        # Sets the selected fontsize only if draw_graticule box from topview options is checked in.
+        if self.appearance_settings["draw_graticule"]:
+            try:
+                self.map._draw_auto_graticule(self.tov_als)
+            except Exception as ex:
+                logging.error("ERROR: cannot plot graticule (message: %s - '%s')", type(ex), ex)
+        else:
+            self.map.set_graticule_visible(self.appearance_settings["draw_graticule"])
+
         ax.set_autoscale_on(False)
-        ax.set_title("Top view", horizontalalignment="left", x=0)
+        ax.set_title("Top view", fontsize=self.tov_pts, horizontalalignment="left", x=0)
         self.draw()  # necessary?
 
         if model:
@@ -1155,6 +1224,13 @@ class MplTopViewCanvas(MplCanvas):
 
         # 2) UPDATE MAP.
         self.map.update_with_coordinate_change(kwargs_update)
+
+        # Sets the graticule ticklabels/labels fontsize for topview when map is redrawn.
+        if self.appearance_settings["draw_graticule"]:
+            self.map.set_graticule_visible(False)
+            self.map._draw_auto_graticule(self.tov_als)
+        else:
+            self.map.set_graticule_visible(self.appearance_settings["draw_graticule"])
         self.draw()  # this one is required to trigger a
         # drawevent to update the background
         # in waypoints_interactor()
@@ -1172,7 +1248,12 @@ class MplTopViewCanvas(MplCanvas):
         if self.kmloverlay:
             self.kmloverlay.update()
 
-        self.draw_metadata("Top view")
+        # self.draw_metadata() ; It is not needed here, since below here already plot title is being set.
+
+        # Setting fontsize for topview plot title when map is redrawn.
+        self.ax.set_title("Top view", fontsize=self.tov_pts, horizontalalignment='left', x=0)
+        self.draw()
+        self.repaint()
 
         # Update in case of a projection change
         self.waypoints_interactor.update()
@@ -1269,13 +1350,17 @@ class MplTopViewCanvas(MplCanvas):
                                                xticks=[], yticks=[],
                                                label="ax2", zorder=0)
                 self.legax.patch.set_facecolor("None")
+                # self.legax.set_yticklabels("ax2", fontsize=32, minor=False)
+                # print("Legax=if" + self.legax)
 
             # If axes exist, adjust their position.
             else:
                 self.legax.set_position([1 - ax_extent_x, 0.01, ax_extent_x, ax_extent_y])
-
+                # self.legax.set_yticklabels("ax2", fontsize=32, minor=False)
+                # print("Legax=else" + self.legax)
             # Plot the new legimg in the legax axes.
             self.legimg = self.legax.imshow(img, origin=PIL_IMAGE_ORIGIN, aspect="equal", interpolation="nearest")
+            # print("Legimg" + self.legimg)
         self.draw()
         # required so that it is actually drawn...
         QtWidgets.QApplication.processEvents()
@@ -1313,6 +1398,8 @@ class MplTopViewCanvas(MplCanvas):
                     "draw_flighttrack": True,
                     "draw_marker": True,
                     "label_flighttrack": True,
+                    "tov_plot_title_size": "default",
+                    "tov_axes_label_size": "default",
                     "colour_water": ((153 / 255.), (255 / 255.), (255 / 255.), (255 / 255.)),
                     "colour_land": ((204 / 255.), (153 / 255.), (102 / 255.), (255 / 255.)),
                     "colour_ft_vertices": (0, 0, 1, 1),
@@ -1320,10 +1407,17 @@ class MplTopViewCanvas(MplCanvas):
         if settings_dict is not None:
             settings.update(settings_dict)
 
+        # Stores the exact value of fontsize for topview plot title size(tov_pts)
+        self.tov_pts = (self.topview_size_settings["plot_title_size"] if settings["tov_plot_title_size"] == "default"
+                        else int(settings["tov_plot_title_size"]))
+        # Stores the exact value of fontsize for topview axes label size(tov_als)
+        self.tov_als = (self.topview_size_settings["axes_label_size"] if settings["tov_axes_label_size"] == "default"
+                        else int(settings["tov_axes_label_size"]))
+
         self.appearance_settings = settings
+        ax = self.ax
 
         if self.map is not None:
-            self.map.set_graticule_visible(settings["draw_graticule"])
             self.map.set_coastlines_visible(settings["draw_coastlines"])
             self.map.set_fillcontinents_visible(visible=settings["fill_continents"],
                                                 land_color=settings["colour_land"],
@@ -1336,6 +1430,18 @@ class MplTopViewCanvas(MplCanvas):
             self.waypoints_interactor.set_vertices_visible(settings["draw_flighttrack"])
             self.waypoints_interactor.set_labels_visible(settings["label_flighttrack"])
 
+            # Updates plot title size as selected from combobox labelled plot title size.
+            ax.set_autoscale_on(False)
+            ax.set_title("Top view", fontsize=self.tov_pts, horizontalalignment="left", x=0)
+
+            # Updates graticule ticklabels/labels fontsize if draw_graticule is True.
+            if settings["draw_graticule"]:
+                self.map.set_graticule_visible(False)
+                self.map._draw_auto_graticule(self.tov_als)
+            else:
+                self.map.set_graticule_visible(settings["draw_graticule"])
+            self.draw()
+
     def set_remote_sensing_appearance(self, settings):
         self.waypoints_interactor.set_remote_sensing(settings["reference"])
         self.waypoints_interactor.set_tangent_visible(settings["draw_tangents"])
